Concepts
========

Ces documents explorent les idées derrière Flask-Jeroboam : comment cela fonctionne, pourquoi c'est conçu de cette façon, et quels compromis nous avons faits.

.. toctree::
   :maxdepth: 1

   architecture_fr
   design-philosophy_fr
   pydantic-integration_fr
